.. pqq documentation master file, created by
   sphinx-quickstart on Tue Feb  7 10:33:12 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to chaneme!
=====================================

This is a library oriented to ...


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api_reference



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
